<?php

/**
 * TeamList for Contao
 *
 * Copyright (c) 2016 Benjamin Roth
 *
 * @license LGPL-3.0+
 */


/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_esm_team']['firstname'][0] = "Vorname";
$GLOBALS['TL_LANG']['tl_esm_team']['firstname'][1] = "Der Vorname des Teammitglieds.";
$GLOBALS['TL_LANG']['tl_esm_team']['lastname'][0] = "Nachname";
$GLOBALS['TL_LANG']['tl_esm_team']['lastname'][1] = "Der Nachname des Teammitglieds.";
$GLOBALS['TL_LANG']['tl_esm_team']['position'][0] = "Position";
$GLOBALS['TL_LANG']['tl_esm_team']['position'][1] = "Die Position der Person im Team/Firma.";
$GLOBALS['TL_LANG']['tl_esm_team']['division'][0] = "Abteilung";
$GLOBALS['TL_LANG']['tl_esm_team']['division'][1] = "Die Abteilung zu welcher das Teammitglied gehört.";
$GLOBALS['TL_LANG']['tl_esm_team']['singleSRC'][0] = "Bild";
$GLOBALS['TL_LANG']['tl_esm_team']['singleSRC'][1] = "Das Portraibild der Person.";
$GLOBALS['TL_LANG']['tl_esm_team']['published'][0] = "Veröffentlicht";
$GLOBALS['TL_LANG']['tl_esm_team']['published'][1] = "Das Teammitglied wird in der Ausgabe angezeigt.";

/**
 * Legends
 */
$GLOBALS['TL_LANG']['tl_esm_team']['title_legend']      = 'Grundeinstellungen';
$GLOBALS['TL_LANG']['tl_esm_team']['company_legend']    = 'Aufgabenbereich im Unternehmen';
$GLOBALS['TL_LANG']['tl_esm_team']['picture_legend']    = 'Bilddefinition';
$GLOBALS['TL_LANG']['tl_esm_team']['publish_legend']    = 'Veröffentlichungseinstellungen';

/**
 * Buttons
 */
$GLOBALS['TL_LANG']['tl_esm_team']['new']               = array('Neues Teammitglied', 'Ein neues Teammitglied hinzufügen');
$GLOBALS['TL_LANG']['tl_esm_team']['toggle']            = array('Mitglied aktiv/inaktiv', 'Teammitglied ID %s aktiv/inaktiv schalten');
$GLOBALS['TL_LANG']['tl_esm_team']['show']              = array('Teammitglieddetails', 'Details des Teammitglieds ID %s anzeigen');
$GLOBALS['TL_LANG']['tl_esm_team']['edit']              = array('Teammitglied bearbeiten', 'Teammitglied ID %s bearbeiten');
$GLOBALS['TL_LANG']['tl_esm_team']['copy']              = array('Teammitglied duplizieren', 'Teammitglied ID %s duplizieren');
$GLOBALS['TL_LANG']['tl_esm_team']['delete']            = array('Teammitglied löschen', 'Teammitglied ID %s löschen');

/**
 * Misc
 */

$GLOBALS['TL_LANG']['tl_esm_team']['includeTemplatesJQuery'] = "Das <em>%s</em>-Template muss im Seitenlayout eingebunden sein.";
