@if not-imported("import_once_func") { @import "import_once_func"; }
@if not-imported("framework") { @import "framework"; }

/*
 ------ HEADER ------
*/
#footer {
  position: relative;
  overflow: hidden;
  //color: $color-text-footer;
  font-size: font-size(14px);
  z-index: 0;
  //background: $color-bg-footer;
  -webkit-background-size: 100% 100%;
  background-size: 100% 100%;

  .-footer-black & {
    background: $color-bg-tertiary url("../images/base/footer_black.jpg") no-repeat 50% 50%;
    -webkit-background-size: 100% 100%;
    background-size: 100% 100%;

    a {
      &:hover,
      &:active {
        color: $color-link;
      }
    }
  }

  a {
    color: $color-text-invert;

    &:hover,
    &:active {
      color: $color-text;
    }
  }

  .inside {
  }

  .mod_customnav {
    margin-bottom: 4.5rem;
    text-align: center;
    .level_1 {
      display: inline-flex;
      justify-content: center;
      flex-wrap: wrap;

      > li {
        padding: 0 15px 15px;
      }
    }
  }

  .social {
    margin-top: 0;

    .footer-social {
      text-align: right;

      @include for-mobile {
        text-align: center;
      }
    }

    .social-wrapper {
      display: inline-block;
      text-align: center;

      p {
        margin-bottom: 0;
      }
      svg {
        font-size: 50px;
      }
    }
  }

  .partner {
    .ce_text {
      display: inline-flex;
      align-items: center;
      justify-content: flex-start;
      white-space: nowrap;

      .image_container {
        margin-left: 1em;
        order:1;
        img {
          opacity: .7;
        }
      }
    }
  }

  .footer-content {
    padding: 0 80px;
  }

  .footer-address {
    font-weight: 400;
    margin-top: 20px;
    h5 {
      font-size: font-size(20px);
      .ff_a {
        font-size: font-size(16px);
        letter-spacing: normal;
      }
    }

    a {
      border-bottom: 1px $color-text-invert solid;
      @include transition(color 0.2s ease, border-color 0.2s ease);

      &:hover,
      &:active {
        border-bottom-color: $color-link;
      }
    }
  }

  .footer-right {
    padding-left: 30px;
  }

  h5 {
    @include small-caps;
    font-size: font-size(22px);
    color: $color-link;
    letter-spacing: normal;
  }

  @include for-tablet {
    .footer-content {
      padding: 0 40px;
    }

    .footer-openinghours,
    .footer-legalnav {
      margin-top: 30px;
    }
    .footer-payment {
      ul {
        justify-content: center;
      }
    }
    .rs-column {
      text-align: center;
    }
    .footer-right {
      padding-left: 0;
    }
  }

  @include for-mobile {
    .footer-content {
      padding: 0 20px;
    }
  }
}
