<?php

/**
 * TeamList for Contao
 *
 * Copyright (c) 2016 Benjamin Roth
 *
 * @license LGPL-3.0+
 */


/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_module']['eSM_team_group'][0] = "Team-Kategorie";
$GLOBALS['TL_LANG']['tl_module']['eSM_team_group'][1] = "Die anzuzeigende Team-Kategorie.";
$GLOBALS['TL_LANG']['tl_module']['eSM_team_divisions'][0] = "Abteilungen";
$GLOBALS['TL_LANG']['tl_module']['eSM_team_divisions'][1] = "Die anzuzeigenden Abteilungen.";

/**
 * Legends
 */
$GLOBALS['TL_LANG']['tl_module']['team_legend']         = 'Team-Einstellungen';
